searchData={"content_type":"text/plain","items":[{"doc":null,"ref":"boxer.html","title":"boxer","type":"module"},{"doc":null,"ref":"boxer.html#add_line_def/2","title":"boxer.add_line_def/2","type":"function"},{"doc":null,"ref":"boxer.html#get_line_char/2","title":"boxer.get_line_char/2","type":"function"},{"doc":null,"ref":"boxer.html#get_line_def/1","title":"boxer.get_line_def/1","type":"function"},{"doc":null,"ref":"boxer.html#print/1","title":"boxer.print/1","type":"function"},{"doc":null,"ref":"boxer.html#print/2","title":"boxer.print/2","type":"function"},{"doc":null,"ref":"boxer.html#wrap/1","title":"boxer.wrap/1","type":"function"},{"doc":null,"ref":"boxer.html#wrap/2","title":"boxer.wrap/2","type":"function"},{"doc":null,"ref":"boxer.html#t:char_key/0","title":"boxer.char_key/0","type":"type"},{"doc":null,"ref":"boxer.html#t:line_def_name/0","title":"boxer.line_def_name/0","type":"type"},{"doc":"# Boxer\n\nWraps a terminal message in boxes.\n\n![sample image](https://github.com/choptastic/boxer/raw/main/priv/boxer-msg.png)","ref":"readme.html","title":"Boxer","type":"extras"},{"doc":"```erlang\n\n{deps, [\n    ...,\n    boxer %% <- add this right here\n]}.\n```","ref":"readme.html#add-to-rebar-config","title":"Add to rebar.config - Boxer","type":"extras"},{"doc":"#","ref":"readme.html#functions","title":"Functions - Boxer","type":"extras"},{"doc":"* `boxer:print(Msg)`: Prints a message with the default box style (single-line)\n* `boxer:print(Msg, LineDefName)`: Prints a message with the specified\n  `LineDefName` (by default, supported are the atoms `single`, `double`, and\n  `hash`).\n* `boxer:wrap(Msg)`: Returns a unicode string list wrapped in the default box\n  style (`single-line`).\n* `boxer:wrap(Msg, LineDefName)`: Returns a unicode string list wrapped in the\n  specified `LineDef`.","ref":"readme.html#printing-and-formatting","title":"Printing and Formatting - Boxer","type":"extras"},{"doc":"You can customize the box-style by creating new definitions (or changing the existing ones)\n\n#","ref":"readme.html#customization","title":"Customization - Boxer","type":"extras"},{"doc":"A Line Definition (Box Style) consists of the following information:\n\n* A name (like `double` or `single`)\n* A map with the following fields:\n\n```erlang\n#{\n    chars =>\n        [Horiz, Vert, TopLeft, TopRight, BottomRight, BottomLeft],\n    h_padding =>\n        HorizontalPadding,\n    v_padding =>\n        VerticalPadding\n}\n```\n\nFor example, the `single` line definition looks like this:\n\n```erlang\n#{\n    chars => \"─│┌┐┘└\",\n    h_padding => 0,\n    v_padding => 0\n}\n```\n\n#","ref":"readme.html#formatting-the-custom-definitions","title":"Formatting the custom definitions - Boxer","type":"extras"},{"doc":"Here's how to add a sample definition that makes a simple border using just periods (dots).\n\n```erlang\nDef = #{chars=>\"......\", h_padding=>1},\nboxer:add_line_def(dots, Def).\n```\n\n#","ref":"readme.html#adding-via-the-erlang-shell","title":"Adding via the Erlang shell - Boxer","type":"extras"},{"doc":"To add the above dot example via config, add the following to your `app.config`:\n\n```erlang\n\n[\n    {boxer, [\n        {boxer_line_defs, [\n            {dots, #{chars=>\"......\", h_padding=>1}}\n        ]}\n    ]}\n].\n```","ref":"readme.html#adding-via-configuration","title":"Adding via configuration - Boxer","type":"extras"},{"doc":"Pull requests and Issues welcome!\n\nThanks!","ref":"readme.html#comments-and-contribution","title":"Comments and Contribution - Boxer","type":"extras"},{"doc":"Copyright 2024 [Jesse Gumm](http://jessegumm.com)\n\nLicensed under the Apache 2.0 License","ref":"readme.html#license-and-copyright","title":"License and Copyright - Boxer","type":"extras"},{"doc":"# Apache License\nVersion 2.0, January 2004\n\nhttp://www.apache.org/licenses/\n\nTERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION","ref":"license.html","title":"Apache License","type":"extras"},{"doc":"\"License\" shall mean the terms and conditions for use, reproduction, and\ndistribution as defined by Sections 1 through 9 of this document.\n\n\"Licensor\" shall mean the copyright owner or entity authorized by the copyright\nowner that is granting the License.\n\n\"Legal Entity\" shall mean the union of the acting entity and all other entities\nthat control, are controlled by, or are under common control with that entity.\nFor the purposes of this definition, \"control\" means (i) the power, direct or\nindirect, to cause the direction or management of such entity, whether by\ncontract or otherwise, or (ii) ownership of fifty percent (50%) or more of the\noutstanding shares, or (iii) beneficial ownership of such entity.\n\n\"You\" (or \"Your\") shall mean an individual or Legal Entity exercising\npermissions granted by this License.\n\n\"Source\" form shall mean the preferred form for making modifications, including\nbut not limited to software source code, documentation source, and configuration\nfiles.\n\n\"Object\" form shall mean any form resulting from mechanical transformation or\ntranslation of a Source form, including but not limited to compiled object code,\ngenerated documentation, and conversions to other media types.\n\n\"Work\" shall mean the work of authorship, whether in Source or Object form, made\navailable under the License, as indicated by a copyright notice that is included\nin or attached to the work (an example is provided in the Appendix below).\n\n\"Derivative Works\" shall mean any work, whether in Source or Object form, that\nis based on (or derived from) the Work and for which the editorial revisions,\nannotations, elaborations, or other modifications represent, as a whole, an\noriginal work of authorship. For the purposes of this License, Derivative Works\nshall not include works that remain separable from, or merely link (or bind by\nname) to the interfaces of, the Work and Derivative Works thereof.\n\n\"Contribution\" shall mean any work of authorship, including the original version\nof the Work and any modifications or additions to that Work or Derivative Works\nthereof, that is intentionally submitted to Licensor for inclusion in the Work\nby the copyright owner or by an individual or Legal Entity authorized to submit\non behalf of the copyright owner. For the purposes of this definition,\n\"submitted\" means any form of electronic, verbal, or written communication sent\nto the Licensor or its representatives, including but not limited to\ncommunication on electronic mailing lists, source code control systems, and\nissue tracking systems that are managed by, or on behalf of, the Licensor for\nthe purpose of discussing and improving the Work, but excluding communication\nthat is conspicuously marked or otherwise designated in writing by the copyright\nowner as \"Not a Contribution.\"\n\n\"Contributor\" shall mean Licensor and any individual or Legal Entity on behalf\nof whom a Contribution has been received by Licensor and subsequently\nincorporated within the Work.","ref":"license.html#1-definitions","title":"1. Definitions. - Apache License","type":"extras"},{"doc":"Subject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable copyright license to reproduce, prepare Derivative Works of,\npublicly display, publicly perform, sublicense, and distribute the Work and such\nDerivative Works in Source or Object form.","ref":"license.html#2-grant-of-copyright-license","title":"2. Grant of Copyright License. - Apache License","type":"extras"},{"doc":"Subject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable (except as stated in this section) patent license to make, have\nmade, use, offer to sell, sell, import, and otherwise transfer the Work, where\nsuch license applies only to those patent claims licensable by such Contributor\nthat are necessarily infringed by their Contribution(s) alone or by combination\nof their Contribution(s) with the Work to which such Contribution(s) was\nsubmitted. If You institute patent litigation against any entity (including a\ncross-claim or counterclaim in a lawsuit) alleging that the Work or a\nContribution incorporated within the Work constitutes direct or contributory\npatent infringement, then any patent licenses granted to You under this License\nfor that Work shall terminate as of the date such litigation is filed.","ref":"license.html#3-grant-of-patent-license","title":"3. Grant of Patent License. - Apache License","type":"extras"},{"doc":"You may reproduce and distribute copies of the Work or Derivative Works thereof\nin any medium, with or without modifications, and in Source or Object form,\nprovided that You meet the following conditions:\n\n1. You must give any other recipients of the Work or Derivative Works a copy of\n   this License; and\n\n2. You must cause any modified files to carry prominent notices stating that\n   You changed the files; and\n\n3. You must retain, in the Source form of any Derivative Works that You\n   distribute, all copyright, patent, trademark, and attribution notices from\n   the Source form of the Work, excluding those notices that do not pertain to\n   any part of the Derivative Works; and\n\n4. If the Work includes a \"NOTICE\" text file as part of its distribution, then\n   any Derivative Works that You distribute must include a readable copy of the\n   attribution notices contained within such NOTICE file, excluding those\n   notices that do not pertain to any part of the Derivative Works, in at least\n   one of the following places: within a NOTICE text file distributed as part\n   of the Derivative Works; within the Source form or documentation, if\n   provided along with the Derivative Works; or, within a display generated by\n   the Derivative Works, if and wherever such third-party notices normally\n   appear. The contents of the NOTICE file are for informational purposes only\n   and do not modify the License. You may add Your own attribution notices\n   within Derivative Works that You distribute, alongside or as an addendum to\n   the NOTICE text from the Work, provided that such additional attribution\n   notices cannot be construed as modifying the License.\n\nYou may add Your own copyright statement to Your modifications and may provide\nadditional or different license terms and conditions for use, reproduction, or\ndistribution of Your modifications, or for any such Derivative Works as a whole,\nprovided Your use, reproduction, and distribution of the Work otherwise complies\nwith the conditions stated in this License.","ref":"license.html#4-redistribution","title":"4. Redistribution. - Apache License","type":"extras"},{"doc":"Unless You explicitly state otherwise, any Contribution intentionally submitted\nfor inclusion in the Work by You to the Licensor shall be under the terms and\nconditions of this License, without any additional terms or conditions.\nNotwithstanding the above, nothing herein shall supersede or modify the terms of\nany separate license agreement you may have executed with Licensor regarding\nsuch Contributions.","ref":"license.html#5-submission-of-contributions","title":"5. Submission of Contributions. - Apache License","type":"extras"},{"doc":"This License does not grant permission to use the trade names, trademarks,\nservice marks, or product names of the Licensor, except as required for\nreasonable and customary use in describing the origin of the Work and\nreproducing the content of the NOTICE file.","ref":"license.html#6-trademarks","title":"6. Trademarks. - Apache License","type":"extras"},{"doc":"Unless required by applicable law or agreed to in writing, Licensor provides the\nWork (and each Contributor provides its Contributions) on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied,\nincluding, without limitation, any warranties or conditions of TITLE, NON-\nINFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are\nsolely responsible for determining the appropriateness of using or\nredistributing the Work and assume any risks associated with Your exercise of\npermissions under this License.","ref":"license.html#7-disclaimer-of-warranty","title":"7. Disclaimer of Warranty. - Apache License","type":"extras"},{"doc":"In no event and under no legal theory, whether in tort (including negligence),\ncontract, or otherwise, unless required by applicable law (such as deliberate\nand grossly negligent acts) or agreed to in writing, shall any Contributor be\nliable to You for damages, including any direct, indirect, special, incidental,\nor consequential damages of any character arising as a result of this License or\nout of the use or inability to use the Work (including but not limited to\ndamages for loss of goodwill, work stoppage, computer failure or malfunction, or\nany and all other commercial damages or losses), even if such Contributor has\nbeen advised of the possibility of such damages.","ref":"license.html#8-limitation-of-liability","title":"8. Limitation of Liability. - Apache License","type":"extras"},{"doc":"While redistributing the Work or Derivative Works thereof, You may choose to\noffer, and charge a fee for, acceptance of support, warranty, indemnity, or\nother liability obligations and/or rights consistent with this License. However,\nin accepting such obligations, You may act only on Your own behalf and on Your\nsole responsibility, not on behalf of any other Contributor, and only if You\nagree to indemnify, defend, and hold each Contributor harmless for any liability\nincurred by, or claims asserted against, such Contributor by reason of your\naccepting any such warranty or additional liability.\n\nEND OF TERMS AND CONDITIONS\n\nCopyright 2024, Jesse Gumm  .\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\nhttp://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"license.html#9-accepting-warranty-or-additional-liability","title":"9. Accepting Warranty or Additional Liability. - Apache License","type":"extras"}]}